@@ -50,8 +50,6 @@ class CGraph extends CGraphGeneral {
 	 */
 	public function get($options = []) {
 		$result = [];
-		$userType = self::$userData['type'];
-		$userid = self::$userData['userid'];
 
 		$sqlParts = [
 			'select'	=> ['graphs' => 'g.graphid'],
@@ -70,7 +68,7 @@ class CGraph extends CGraphGeneral {
 			'itemids'					=> null,
 			'templated'					=> null,
 			'inherited'					=> null,
-			'editable'					=> null,
+			'editable'					=> false,
 			'nopermissions'				=> null,
 			// filter
 			'filter'					=> null,
@@ -98,10 +96,9 @@ class CGraph extends CGraphGeneral {
 		$options = zbx_array_merge($defOptions, $options);
 
 		// permission check
-		if ($userType != USER_TYPE_SUPER_ADMIN && !$options['nopermissions']) {
+		if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN && !$options['nopermissions']) {
 			$permission = $options['editable'] ? PERM_READ_WRITE : PERM_READ;
-
-			$userGroups = getUserGroupsByUserId($userid);
+			$userGroups = getUserGroupsByUserId(self::$userData['userid']);
 
 			// check permissions by graph items
 			$sqlParts['where'][] = 'NOT EXISTS ('.
