@@ -36,11 +36,11 @@ class CHistory extends CApiService {
 	/**
 	 * Get history data.
 	 *
-	 * @param array $options
-	 * @param array $options['itemids']
-	 * @param boolean $options['editable']
+	 * @param array  $options
+	 * @param array  $options['itemids']
+	 * @param bool   $options['editable']
 	 * @param string $options['pattern']
-	 * @param int $options['limit']
+	 * @param int    $options['limit']
 	 * @param string $options['order']
 	 *
 	 * @return array|int item data as array or false if error
@@ -61,22 +61,22 @@ class CHistory extends CApiService {
 			'history'					=> ITEM_VALUE_TYPE_UINT64,
 			'hostids'					=> null,
 			'itemids'					=> null,
-			'editable'					=> null,
+			'editable'					=> false,
 			'nopermissions'				=> null,
 			// filter
 			'filter'					=> null,
 			'search'					=> null,
 			'searchByAny'				=> null,
-			'startSearch'				=> null,
-			'excludeSearch'				=> null,
+			'startSearch'				=> false,
+			'excludeSearch'				=> false,
 			'searchWildcardsEnabled'	=> null,
 			'time_from'					=> null,
 			'time_till'					=> null,
 			// output
 			'output'					=> API_OUTPUT_EXTEND,
-			'countOutput'				=> null,
-			'groupCount'				=> null,
-			'preservekeys'				=> null,
+			'countOutput'				=> false,
+			'groupCount'				=> false,
+			'preservekeys'				=> false,
 			'sortfield'					=> '',
 			'sortorder'					=> '',
 			'limit'						=> null
@@ -144,12 +144,12 @@ class CHistory extends CApiService {
 		}
 
 		// countOutput
-		if (!is_null($options['countOutput'])) {
+		if ($options['countOutput']) {
 			$options['sortfield'] = '';
 			$sqlParts['select'] = ['count(DISTINCT h.hostid) as rowscount'];
 
 			// groupCount
-			if (!is_null($options['groupCount'])) {
+			if ($options['groupCount']) {
 				foreach ($sqlParts['group'] as $key => $fields) {
 					$sqlParts['select'][$key] = $fields;
 				}
@@ -198,7 +198,7 @@ class CHistory extends CApiService {
 			}
 		}
 
-		if (is_null($options['preservekeys'])) {
+		if (!$options['preservekeys']) {
 			$result = zbx_cleanHashes($result);
 		}
 		return $result;
