@@ -37,8 +37,6 @@ class CHostGroup extends CApiService {
 	 */
 	public function get($params) {
 		$result = [];
-		$userType = self::$userData['type'];
-		$userid = self::$userData['userid'];
 
 		$sqlParts = [
 			'select'	=> ['groups' => 'g.groupid'],
@@ -68,14 +66,14 @@ class CHostGroup extends CApiService {
 			'with_monitored_httptests'	=> null,
 			'with_graphs'				=> null,
 			'with_applications'			=> null,
-			'editable'					=> null,
+			'editable'					=> false,
 			'nopermissions'				=> null,
 			// filter
 			'filter'					=> null,
 			'search'					=> null,
 			'searchByAny'				=> null,
-			'startSearch'				=> null,
-			'excludeSearch'				=> null,
+			'startSearch'				=> false,
+			'excludeSearch'				=> false,
 			'searchWildcardsEnabled'	=> null,
 			// output
 			'output'					=> API_OUTPUT_EXTEND,
@@ -83,9 +81,9 @@ class CHostGroup extends CApiService {
 			'selectTemplates'			=> null,
 			'selectGroupDiscovery'		=> null,
 			'selectDiscoveryRule'		=> null,
-			'countOutput'				=> null,
-			'groupCount'				=> null,
-			'preservekeys'				=> null,
+			'countOutput'				=> false,
+			'groupCount'				=> false,
+			'preservekeys'				=> false,
 			'sortfield'					=> '',
 			'sortorder'					=> '',
 			'limit'						=> null,
@@ -94,10 +92,9 @@ class CHostGroup extends CApiService {
 		$options = zbx_array_merge($defOptions, $params);
 
 		// editable + PERMISSION CHECK
-		if ($userType != USER_TYPE_SUPER_ADMIN && !$options['nopermissions']) {
+		if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN && !$options['nopermissions']) {
 			$permission = $options['editable'] ? PERM_READ_WRITE : PERM_READ;
-
-			$userGroups = getUserGroupsByUserId($userid);
+			$userGroups = getUserGroupsByUserId(self::$userData['userid']);
 
 			$sqlParts['where'][] = 'EXISTS ('.
 				'SELECT NULL'.
@@ -317,8 +314,8 @@ class CHostGroup extends CApiService {
 		$sqlParts = $this->applyQuerySortOptions($this->tableName(), $this->tableAlias(), $options, $sqlParts);
 		$res = DBselect($this->createSelectQueryFromParts($sqlParts), $sqlParts['limit']);
 		while ($group = DBfetch($res)) {
-			if (!is_null($options['countOutput'])) {
-				if (!is_null($options['groupCount'])) {
+			if ($options['countOutput']) {
+				if ($options['groupCount']) {
 					$result[] = $group;
 				}
 				else {
@@ -330,7 +327,7 @@ class CHostGroup extends CApiService {
 			}
 		}
 
-		if (!is_null($options['countOutput'])) {
+		if ($options['countOutput']) {
 			return $result;
 		}
 
@@ -339,142 +336,149 @@ class CHostGroup extends CApiService {
 		}
 
 		// removing keys (hash -> array)
-		if (is_null($options['preservekeys'])) {
+		if (!$options['preservekeys']) {
 			$result = zbx_cleanHashes($result);
 		}
 		return $result;
 	}
 
 	/**
-	 * Create host groups.
+	 * Inherit rights from parent host groups.
 	 *
-	 * @param array $groups array with host group names
-	 * @param array $groups['name']
+	 * @param array  $groups
+	 * @param string $groups[]['groupid']
+	 * @param string $groups[]['name']
+	 *
+	 * @return array
+	 */
+	private function inheritRights(array $groups) {
+		$parent_names = [];
+
+		foreach ($groups as $group) {
+			if (($pos = strrpos($group['name'], '/')) === false) {
+				continue;
+			}
+
+			$parent_names[substr($group['name'], 0, $pos)][] = $group['groupid'];
+		}
+
+		if ($parent_names) {
+			$db_parent_groups = DB::select('groups', [
+				'output' => ['groupid', 'name'],
+				'filter' => ['name' => array_keys($parent_names)]
+			]);
+
+			$parent_groupids = [];
+
+			foreach ($db_parent_groups as $db_parent_group) {
+				$parent_groupids[$db_parent_group['groupid']] = $parent_names[$db_parent_group['name']];
+			}
+
+			if ($parent_groupids) {
+				$db_rights = DB::select('rights', [
+					'output' => ['groupid', 'id', 'permission'],
+					'filter' => ['id' => array_keys($parent_groupids)]
+				]);
+
+				$rights = [];
+
+				foreach ($db_rights as $db_right) {
+					foreach ($parent_groupids[$db_right['id']] as $groupid) {
+						$rights[] = [
+							'groupid' => $db_right['groupid'],
+							'permission' => $db_right['permission'],
+							'id' => $groupid
+						];
+					}
+				}
+
+				DB::insertBatch('rights', $rights);
+			}
+		}
+	}
+
+	/**
+	 * @param array  $groups
 	 *
 	 * @return array
 	 */
 	public function create(array $groups) {
-		$groups = zbx_toArray($groups);
-
 		$this->validateCreate($groups);
 
-		$groupids = [];
-		$groupids_with_rights = [];
-		$parent_children = [];
+		$groupids = DB::insertBatch('groups', $groups);
 
-		foreach ($groups as $group) {
-			$new_groupids = DB::insert('groups', [$group]);
-			$groupid = reset($new_groupids);
-			$groupids[] = $groupid;
-
-			$name_parts = explode('/', $group['name']);
-			if (count($name_parts) > 1) {
-				array_pop($name_parts);
-				$parents = $this->get([
-					'output' => ['groupid'],
-					'filter' => ['name' => implode('/', $name_parts)],
-					'limit' => 1
-				]);
-
-				if ($parents) {
-					$parent = reset($parents);
-					$groupids_with_rights[$groupid] = $parent['groupid'];
-					$parent_children[$parent['groupid']][] = $groupid;
-				}
-			}
+		foreach ($groups as $index => &$group) {
+			$group['groupid'] = $groupids[$index];
 		}
+		unset($group);
 
-		if ($groupids_with_rights) {
-			$rights = DBSelect(
-				'SELECT r.groupid, r.permission, r.id'.
-				' FROM rights r'.
-				' WHERE '.dbConditionInt('r.id', $groupids_with_rights)
-			);
+		$this->inheritRights($groups);
 
-			$rights_to_insert = [];
-
-			while ($right = DBfetch($rights)) {
-				foreach ($parent_children[$right['id']] as $parent_child) {
-					$rights_to_insert[] = [
-						'groupid' => $right['groupid'],
-						'permission' => $right['permission'],
-						'id' => $parent_child
-					];
-				}
-			}
-
-			DB::insert('rights', $rights_to_insert);
-		}
+		$this->addAuditBulk(AUDIT_ACTION_ADD, AUDIT_RESOURCE_HOST_GROUP, $groups);
 
 		return ['groupids' => $groupids];
 	}
 
 	/**
-	 * Update host groups.
+	 * @param array  $groups
 	 *
-	 * @param array $groups
-	 * @param array $groups[0]['name'], ...
-	 * @param array $groups[0]['groupid'], ...
-	 *
-	 * @return boolean
+	 * @return array
 	 */
 	public function update(array $groups) {
-		$groups = zbx_toArray($groups);
-
-		$db_groups = [];
 		$this->validateUpdate($groups, $db_groups);
 
-		$update = [];
+		$upd_groups = [];
 
 		foreach ($groups as $group) {
-			// Skip update if name has not changed.
-			if (array_key_exists('name', $group) && $group['name'] !== $db_groups[$group['groupid']]['name']) {
-				$update[] = [
+			$db_group = $db_groups[$group['groupid']];
+
+			if (array_key_exists('name', $group) && $group['name'] !== $db_group['name']) {
+				$upd_groups[] = [
 					'values' => ['name' => $group['name']],
 					'where' => ['groupid' => $group['groupid']]
 				];
 			}
 		}
 
-		if ($update) {
-			DB::update('groups', $update);
-		}
+		DB::update('groups', $upd_groups);
+
+		$this->addAuditBulk(AUDIT_ACTION_UPDATE, AUDIT_RESOURCE_HOST_GROUP, $groups, $db_groups);
 
 		return ['groupids' => zbx_objectValues($groups, 'groupid')];
 	}
 
 	/**
-	 * Delete host groups.
-	 *
 	 * @param array $groupids
 	 * @param bool 	$nopermissions
 	 *
 	 * @return array
 	 */
 	public function delete(array $groupids, $nopermissions = false) {
-		if (empty($groupids)) {
-			self::exception(ZBX_API_ERROR_PARAMETERS, _('Empty input parameter.'));
+		$api_input_rules = ['type' => API_IDS, 'flags' => API_NOT_EMPTY, 'uniq' => true];
+		if (!CApiInputValidator::validate($api_input_rules, $groupids, '/', $error)) {
+			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 		}
-		sort($groupids);
 
-		$delGroups = $this->get([
+		$db_groups = $this->get([
+			'output' => ['groupid', 'name', 'internal'],
 			'groupids' => $groupids,
 			'editable' => true,
-			'output' => ['groupid', 'name', 'internal'],
 			'selectHosts' => ['hostid', 'host'],
 			'selectTemplates' => ['templateid', 'host'],
 			'preservekeys' => true,
 			'nopermissions' => $nopermissions
 		]);
+
 		foreach ($groupids as $groupid) {
-			if (!isset($delGroups[$groupid])) {
+			if (!array_key_exists($groupid, $db_groups)) {
 				self::exception(ZBX_API_ERROR_PERMISSIONS,
 					_('No permissions to referred object or it does not exist!')
 				);
 			}
-			if ($delGroups[$groupid]['internal'] == ZBX_INTERNAL_GROUP) {
+			if ($db_groups[$groupid]['internal'] == ZBX_INTERNAL_GROUP) {
 				self::exception(ZBX_API_ERROR_PARAMETERS,
-					_s('Host group "%1$s" is internal and can not be deleted.', $delGroups[$groupid]['name']));
+					_s('Host group "%1$s" is internal and can not be deleted.', $db_groups[$groupid]['name'])
+				);
 			}
 		}
 
@@ -488,7 +492,7 @@ class CHostGroup extends CApiService {
 		if ($groupPrototype) {
 			self::exception(ZBX_API_ERROR_PARAMETERS,
 				_s('Group "%1$s" cannot be deleted, because it is used by a host prototype.',
-					$delGroups[$groupPrototype['groupid']]['name']
+					$db_groups[$groupPrototype['groupid']]['name']
 				)
 			);
 		}
@@ -496,12 +500,12 @@ class CHostGroup extends CApiService {
 		$hosts_to_unlink = [];
 		$templates_to_unlink = [];
 
-		foreach ($delGroups as $group) {
-			foreach ($group['hosts'] as $host) {
+		foreach ($db_groups as $db_group) {
+			foreach ($db_group['hosts'] as $host) {
 				$hosts_to_unlink[] = $host;
 			}
 
-			foreach ($group['templates'] as $template) {
+			foreach ($db_group['templates'] as $template) {
 				$templates_to_unlink[] = $template;
 			}
 		}
@@ -521,7 +525,7 @@ class CHostGroup extends CApiService {
 				}
 				self::exception(ZBX_API_ERROR_PARAMETERS,
 					_s('Host group "%1$s" cannot be deleted, because it is used in a global script.',
-						$delGroups[$script['groupid']]['name']
+						$db_groups[$script['groupid']]['name']
 					)
 				);
 			}
@@ -537,7 +541,7 @@ class CHostGroup extends CApiService {
 		if ($corr_condition_group) {
 			self::exception(ZBX_API_ERROR_PARAMETERS,
 				_s('Group "%1$s" cannot be deleted, because it is used in a correlation condition.',
-					$delGroups[$corr_condition_group['groupid']]['name']
+					$db_groups[$corr_condition_group['groupid']]['name']
 				)
 			);
 		}
@@ -646,78 +650,22 @@ class CHostGroup extends CApiService {
 
 		DB::delete('groups', ['groupid' => $groupids]);
 
-		DB::delete('profiles', [
-			'idx' => ['web.dashconf.groups.groupids', 'web.dashconf.groups.hide.groupids'],
-			'value_id' => $groupids
-		]);
-
-		// TODO: remove audit
-		foreach ($groupids as $groupid) {
-			add_audit_ext(AUDIT_ACTION_DELETE, AUDIT_RESOURCE_HOST_GROUP, $groupid, $delGroups[$groupid]['name'], 'groups', null, null);
-		}
+		$this->addAuditBulk(AUDIT_ACTION_DELETE, AUDIT_RESOURCE_HOST_GROUP, $db_groups);
 
 		return ['groupids' => $groupids];
 	}
 
 	/**
-	 * Validates the input parameters for the create() method.
+	 * Check for duplicated host groups.
 	 *
-	 * @param array $groups
+	 * @param array  $names
 	 *
-	 * @throws APIException if the input is invalid.
+	 * @throws APIException  if host group already exists.
 	 */
-	protected function validateCreate(array $groups) {
-		if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN) {
-			self::exception(ZBX_API_ERROR_PERMISSIONS, _('Only Super Admins can create host groups.'));
-		}
-
-		if (!$groups) {
-			self::exception(ZBX_API_ERROR_PARAMETERS, _('Empty input parameter.'));
-		}
-
-		$host_group_name_validator = new CHostGroupNameValidator();
-
-		$required_fields = ['name'];
-
-		foreach ($groups as $group) {
-			// Validate required fields and check if "name" is not empty.
-			if (!is_array($group)) {
-				self::exception(ZBX_API_ERROR_PARAMETERS, _('Incorrect arguments passed to function.'));
-			}
-
-			// Check required parameters.
-			$missing_keys = array_diff($required_fields, array_keys($group));
-
-			if ($missing_keys) {
-				self::exception(ZBX_API_ERROR_PARAMETERS,
-					_s('Host group is missing parameters: %1$s', implode(', ', $missing_keys))
-				);
-			}
-
-			// Check if host group name is valid.
-			if (!$host_group_name_validator->validate($group['name'])) {
-				self::exception(ZBX_API_ERROR_PARAMETERS,
-					_s('Incorrect value for field "%1$s": %2$s.', 'name', $host_group_name_validator->getError())
-				);
-			}
-
-			$this->checkNoParameters($group, ['internal'], _('Cannot set "%1$s" for host group "%2$s".'),
-				$group['name']
-			);
-		}
-
-		// Check for duplicate names.
-		$duplicate = CArrayHelper::findDuplicate($groups, 'name');
-		if ($duplicate) {
-			self::exception(ZBX_API_ERROR_PARAMETERS,
-				_s('Duplicate "%1$s" value "%2$s" for host group.', 'name', $duplicate['name'])
-			);
-		}
-
-		// Check if host group already exists.
-		$db_groups = API::getApiService()->select('groups', [
+	private function checkDuplicates(array $names) {
+		$db_groups = DB::select('groups', [
 			'output' => ['name'],
-			'filter' => ['name' => zbx_objectValues($groups, 'name')],
+			'filter' => ['name' => $names],
 			'limit' => 1
 		]);
 
@@ -729,35 +677,53 @@ class CHostGroup extends CApiService {
 	}
 
 	/**
-	 * Validates the input parameters for the update() method.
+	 * @param array $groups
 	 *
+	 * @throws APIException if the input is invalid.
+	 */
+	protected function validateCreate(array &$groups) {
+		if (self::$userData['type'] != USER_TYPE_SUPER_ADMIN) {
+			self::exception(ZBX_API_ERROR_PERMISSIONS, _('Only Super Admins can create host groups.'));
+		}
+
+		$api_input_rules = ['type' => API_OBJECTS, 'flags' => API_NOT_EMPTY | API_NORMALIZE, 'uniq' => [['name']], 'fields' => [
+			'name' =>	['type' => API_HG_NAME, 'flags' => API_REQUIRED, 'length' => DB::getFieldLength('groups', 'name')]
+		]];
+		if (!CApiInputValidator::validate($api_input_rules, $groups, '/', $error)) {
+			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
+		}
+
+		$this->checkDuplicates(zbx_objectValues($groups, 'name'));
+	}
+
+	/**
 	 * @param array $groups
 	 * @param array $db_groups
 	 *
 	 * @throws APIException if the input is invalid.
 	 */
-	protected function validateUpdate(array $groups, array &$db_groups) {
-		if (!$groups) {
-			self::exception(ZBX_API_ERROR_PARAMETERS, _('Empty input parameter.'));
+	protected function validateUpdate(array &$groups, array &$db_groups = null) {
+		$api_input_rules = ['type' => API_OBJECTS, 'flags' => API_NOT_EMPTY | API_NORMALIZE, 'uniq' => [['groupid'], ['name']], 'fields' => [
+			'groupid' =>	['type' => API_ID, 'flags' => API_REQUIRED],
+			'name' =>		['type' => API_HG_NAME, 'length' => DB::getFieldLength('groups', 'name')]
+		]];
+		if (!CApiInputValidator::validate($api_input_rules, $groups, '/', $error)) {
+			self::exception(ZBX_API_ERROR_PARAMETERS, $error);
 		}
 
-		// Validate given IDs.
-		$this->checkObjectIds($groups, 'groupid',
-			_('No "%1$s" given for group.'),
-			_('Empty group ID.'),
-			_('Incorrect group ID.')
-		);
-
 		// permissions
 		$db_groups = $this->get([
-			'output' => ['groupid', 'flags', 'name'],
+			'output' => ['groupid', 'name', 'flags'],
 			'groupids' => zbx_objectValues($groups, 'groupid'),
 			'editable' => true,
 			'preservekeys' => true
 		]);
 
-		$check_names = [];
-		$host_group_name_validator = new CHostGroupNameValidator();
+		$update_discovered_validator = new CUpdateDiscoveredValidator([
+			'messageAllowed' => _('Cannot update a discovered host group.')
+		]);
+
+		$names = [];
 
 		foreach ($groups as $group) {
 			if (!array_key_exists($group['groupid'], $db_groups)) {
@@ -766,55 +732,17 @@ class CHostGroup extends CApiService {
 				);
 			}
 
-			// Check if host group name is valid.
-			if (array_key_exists('name', $group)) {
-				if (!$host_group_name_validator->validate($group['name'])) {
-					self::exception(ZBX_API_ERROR_PARAMETERS,
-						_s('Incorrect value for field "%1$s": %2$s.', 'name', $host_group_name_validator->getError())
-					);
-				}
+			$db_group = $db_groups[$group['groupid']];
 
-				if ($db_groups[$group['groupid']]['name'] !== $group['name']) {
-					$check_names[] = $group;
-				}
+			$this->checkPartialValidator($group, $update_discovered_validator, $db_group);
+
+			if (array_key_exists('name', $group) && $group['name'] !== $db_group['name']) {
+				$names[] = $group['name'];
 			}
 		}
 
-		if ($check_names) {
-			// Check for duplicate names.
-			$duplicate = CArrayHelper::findDuplicate($check_names, 'name');
-			if ($duplicate) {
-				self::exception(ZBX_API_ERROR_PARAMETERS,
-					_s('Duplicate "%1$s" value "%2$s" for host group.', 'name', $duplicate['name'])
-				);
-			}
-
-			// Check if group already exists.
-			$db_group_names = API::getApiService()->select('groups', [
-				'output' => ['groupid', 'name'],
-				'filter' => ['name' => zbx_objectValues($check_names, 'name')]
-			]);
-			$db_group_names = zbx_toHash($db_group_names, 'name');
-
-			foreach ($check_names as $group) {
-				if (array_key_exists($group['name'], $db_group_names)
-						&& bccomp($db_group_names[$group['name']]['groupid'], $group['groupid']) != 0) {
-					self::exception(ZBX_API_ERROR_PARAMETERS, _s('Host group "%1$s" already exists.', $group['name']));
-				}
-			}
-		}
-
-		$update_discovered_validator = new CUpdateDiscoveredValidator([
-			'messageAllowed' => _('Cannot update a discovered host group.')
-		]);
-
-		foreach ($groups as $group) {
-			$this->checkNoParameters($group, ['internal'], _('Cannot update "%1$s" for host group "%2$s".'),
-				array_key_exists('name', $group) ? $group['name'] : $db_groups[$group['groupid']]['name']
-			);
-
-			// Cannot update discovered host groups.
-			$this->checkPartialValidator($group, $update_discovered_validator, $db_groups[$group['groupid']]);
+		if ($names) {
+			$this->checkDuplicates($names);
 		}
 	}
 
@@ -1030,10 +958,18 @@ class CHostGroup extends CApiService {
 			}
 		}
 
-		if ($groupIdsToAdd && !$this->isWritable($groupIdsToAdd)) {
-			self::exception(ZBX_API_ERROR_PERMISSIONS,
-				_('No permissions to referred object or it does not exist!')
-			);
+		if ($groupIdsToAdd) {
+			$count = $this->get([
+				'countOutput' => true,
+				'groupids' => $groupIdsToAdd,
+				'editable' => true
+			]);
+
+			if ($count != count($groupIdsToAdd)) {
+				self::exception(ZBX_API_ERROR_PERMISSIONS,
+					_('No permissions to referred object or it does not exist!')
+				);
+			}
 		}
 	}
 
@@ -1151,13 +1087,21 @@ class CHostGroup extends CApiService {
 		}
 
 		// Continue to check new, existing or removable groups for given hosts and templates.
-		$groupIdsToUpdate = array_merge($groupIdsToAdd, $groupIdsToRemove);
+		$groupIdsToUpdate = $groupIdsToAdd + $groupIdsToRemove;
 
 		// Validate write permissions only to changed (added/removed) groups for given hosts and templates.
-		if ($groupIdsToUpdate && !$this->isWritable($groupIdsToUpdate)) {
-			self::exception(ZBX_API_ERROR_PERMISSIONS,
-				_('No permissions to referred object or it does not exist!')
-			);
+		if ($groupIdsToUpdate) {
+			$count = $this->get([
+				'countOutput' => true,
+				'groupids' => $groupIdsToUpdate,
+				'editable' => true
+			]);
+
+			if ($count != count($groupIdsToUpdate)) {
+				self::exception(ZBX_API_ERROR_PERMISSIONS,
+					_('No permissions to referred object or it does not exist!')
+				);
+			}
 		}
 
 		// Check if groups can be removed from given hosts and templates. Only check if no groups are added.
@@ -1268,10 +1212,18 @@ class CHostGroup extends CApiService {
 			}
 		}
 
-		if ($groupIdsToRemove && !$this->isWritable($groupIdsToRemove)) {
-			self::exception(ZBX_API_ERROR_PERMISSIONS,
-				_('No permissions to referred object or it does not exist!')
-			);
+		if ($groupIdsToRemove) {
+			$count = $this->get([
+				'countOutput' => true,
+				'groupids' => $groupIdsToRemove,
+				'editable' => true
+			]);
+
+			if ($count != count($groupIdsToRemove)) {
+				self::exception(ZBX_API_ERROR_PERMISSIONS,
+					_('No permissions to referred object or it does not exist!')
+				);
+			}
 		}
 
 		$this->verifyHostsAndTemplatesAreUnlinkable($hosts_to_unlink, $templates_to_unlink, $groupIdsToRemove);
@@ -1295,56 +1247,6 @@ class CHostGroup extends CApiService {
 		}
 	}
 
-	/**
-	 * Check if user has read permissions for host groups.
-	 *
-	 * @param array $ids
-	 *
-	 * @return bool
-	 */
-	public function isReadable(array $ids) {
-		if (!is_array($ids)) {
-			return false;
-		}
-		if (empty($ids)) {
-			return true;
-		}
-
-		$ids = array_unique($ids);
-
-		$count = $this->get([
-			'groupids' => $ids,
-			'countOutput' => true
-		]);
-		return count($ids) == $count;
-	}
-
-	/**
-	 * Check if user has write permissions for host groups.
-	 *
-	 * @param array $ids
-	 *
-	 * @return bool
-	 */
-	public function isWritable(array $ids) {
-		if (!is_array($ids)) {
-			return false;
-		}
-		if (empty($ids)) {
-			return true;
-		}
-
-		$ids = array_unique($ids);
-
-		$count = $this->get([
-			'groupids' => $ids,
-			'editable' => true,
-			'countOutput' => true
-		]);
-
-		return count($ids) == $count;
-	}
-
 	protected function addRelatedObjects(array $options, array $result) {
 		$result = parent::addRelatedObjects($options, $result);
 
