@@ -659,7 +659,10 @@ class CPieGraphDraw extends CGraphDraw {
 	}
 
 	public function draw() {
-		$start_time = microtime(true);
+		$debug_mode = CWebUser::getDebugMode();
+		if ($debug_mode) {
+			$start_time = microtime(true);
+		}
 		set_image_header();
 
 		$this->selectData();
@@ -747,23 +750,24 @@ class CPieGraphDraw extends CGraphDraw {
 				$this->drawElementPie($values);
 		}
 
-		$this->drawLogo();
 		if ($this->drawLegend == 1) {
 			$this->drawLegend();
 		}
 
-		$str = sprintf('%0.2f', microtime(true) - $start_time);
-		$str = _s('Data from %1$s. Generated in %2$s sec.', $this->dataFrom, $str);
-		$strSize = imageTextSize(6, 0, $str);
-		imageText(
-			$this->im,
-			6,
-			0,
-			$this->fullSizeX - $strSize['width'] - 5,
-			$this->fullSizeY - 5,
-			$this->getColor('Gray'),
-			$str
-		);
+		if ($debug_mode) {
+			$str = sprintf('%0.2f', microtime(true) - $start_time);
+			$str = _s('Data from %1$s. Generated in %2$s sec.', $this->dataFrom, $str);
+			$str_size = imageTextSize(6, 0, $str);
+			imageText(
+				$this->im,
+				6,
+				0,
+				$this->fullSizeX - $str_size['width'] - 5,
+				$this->fullSizeY - 5,
+				$this->getColor('Gray'),
+				$str
+			);
+		}
 
 		unset($this->items, $this->data);
 
