@@ -144,7 +144,7 @@ class CMapHelper {
 		processAreasCoordinates($sysmap, $areas, $map_info);
 		add_elementNames($sysmap['selements']);
 
-		foreach ($sysmap['selements'] as $id => $element) {
+		foreach ($sysmap['selements'] as $id => &$element) {
 			switch ($element['elementtype']) {
 				case SYSMAP_ELEMENT_TYPE_IMAGE:
 					$map_info[$id]['name'] = _('Image');
@@ -160,6 +160,25 @@ class CMapHelper {
 					} else {
 						$map_info[$id]['name'] = '';
 					}
+
+					// Move the trigger with problem and highiest priority to the beginning of the trigger list.
+					if (array_key_exists('triggerid', $map_info[$id])) {
+						$trigger_pos = 0;
+
+						foreach ($element['elements'] as $i => $trigger) {
+							if ($trigger['triggerid'] == $map_info[$id]['triggerid']) {
+								$trigger_pos = $i;
+								break;
+							}
+						}
+
+						if ($trigger_pos > 0) {
+							$trigger = $element['elements'][$trigger_pos];
+							unset($element['elements'][$trigger_pos]);
+							array_unshift($element['elements'], $trigger);
+						}
+					}
+
 					break;
 
 				default:
@@ -167,6 +186,7 @@ class CMapHelper {
 					break;
 			}
 		}
+		unset($element);
 
 		$labels = getMapLabels($sysmap, $map_info, true);
 		$highlights = getMapHighligts($sysmap, $map_info);
@@ -440,4 +460,68 @@ class CMapHelper {
 
 		return true;
 	}
+
+	/**
+	 * Set labels inherited from map configuration data.
+	 *
+	 * @param array $map
+	 *
+	 * @return array map with inherited labels set for elements.
+	 */
+	public static function setElementInheritedLabels(array $map) {
+		foreach ($map['selements'] as &$selement) {
+			$selement['inherited_label'] = null;
+			$selement['label_type'] = $map['label_type'];
+
+			if ($map['label_format'] != SYSMAP_LABEL_ADVANCED_OFF) {
+				switch ($selement['elementtype']) {
+					case SYSMAP_ELEMENT_TYPE_HOST_GROUP:
+						$selement['label_type'] = $map['label_type_hostgroup'];
+						if ($map['label_type_hostgroup'] == MAP_LABEL_TYPE_CUSTOM) {
+							$selement['inherited_label'] = $map['label_string_hostgroup'];
+						}
+						break;
+
+					case SYSMAP_ELEMENT_TYPE_HOST:
+						$selement['label_type'] = $map['label_type_host'];
+						if ($map['label_type_host'] == MAP_LABEL_TYPE_CUSTOM) {
+							$selement['inherited_label'] = $map['label_string_host'];
+						}
+						break;
+
+					case SYSMAP_ELEMENT_TYPE_TRIGGER:
+						$selement['label_type'] = $map['label_type_trigger'];
+						if ($map['label_type_trigger'] == MAP_LABEL_TYPE_CUSTOM) {
+							$selement['inherited_label'] = $map['label_string_trigger'];
+						}
+						break;
+
+					case SYSMAP_ELEMENT_TYPE_MAP:
+						$selement['label_type'] = $map['label_type_map'];
+						if ($map['label_type_map'] == MAP_LABEL_TYPE_CUSTOM) {
+							$selement['inherited_label'] = $map['label_string_map'];
+						}
+						break;
+
+					case SYSMAP_ELEMENT_TYPE_IMAGE:
+						$selement['label_type'] = $map['label_type_image'];
+						if ($map['label_type_image'] == MAP_LABEL_TYPE_CUSTOM) {
+							$selement['inherited_label'] = $map['label_string_image'];
+						}
+						break;
+				}
+			}
+
+			if ($selement['label_type'] == MAP_LABEL_TYPE_NOTHING) {
+				$selement['inherited_label'] = '';
+			}
+			elseif ($selement['label_type'] == MAP_LABEL_TYPE_IP
+					&& $selement['elementtype'] == SYSMAP_ELEMENT_TYPE_HOST) {
+				$selement['inherited_label'] = '{HOST.IP}';
+			}
+		}
+		unset($selement);
+
+		return $map;
+	}
 }
