@@ -64,6 +64,15 @@ class CImportReferencer {
 	protected $httptestsRefs;
 	protected $httpstepsRefs;
 
+	/**
+	 * Initializes references for items.
+	 */
+	public function initItemsReferences() {
+		if ($this->itemsRefs === null) {
+			$this->selectItems();
+		}
+	}
+
 	/**
 	 * Get group id by name.
 	 *
@@ -1068,8 +1077,7 @@ class CImportReferencer {
 			$dbProxy = API::Proxy()->get([
 				'filter' => ['host' => $this->proxies],
 				'output' => ['hostid', 'host'],
-				'preservekeys' => true,
-				'editable' => true
+				'preservekeys' => true
 			]);
 			foreach ($dbProxy as $proxy) {
 				$this->proxiesRefs[$proxy['host']] = $proxy['proxyid'];
