@@ -104,6 +104,37 @@ switch ($page['type']) {
 	case PAGE_TYPE_HTML:
 	default:
 		header('Content-Type: text/html; charset=UTF-8');
+		header('X-Content-Type-Options: nosniff');
+		header('X-XSS-Protection: 1; mode=block');
+
+		if (X_FRAME_OPTIONS !== null) {
+			if (strcasecmp(X_FRAME_OPTIONS, 'SAMEORIGIN') == 0 || strcasecmp(X_FRAME_OPTIONS, 'DENY') == 0) {
+				$x_frame_options = X_FRAME_OPTIONS;
+			}
+			else {
+				$x_frame_options = 'SAMEORIGIN';
+				$allowed_urls = explode(',', X_FRAME_OPTIONS);
+				$url_to_check = array_key_exists('HTTP_REFERER', $_SERVER)
+					? parse_url($_SERVER['HTTP_REFERER'], PHP_URL_HOST)
+					: null;
+
+				if ($url_to_check) {
+					foreach ($allowed_urls as $allowed_url) {
+						if (strcasecmp(trim($allowed_url), $url_to_check) == 0) {
+							$x_frame_options = 'ALLOW-FROM '.$allowed_url;
+							break;
+						}
+					}
+				}
+			}
+
+			header('X-Frame-Options: '.$x_frame_options);
+		}
+
+		if ((array_key_exists('https', $_SERVER) && ($_SERVER['https'] == 1 || $_SERVER['https'] === 'on'))
+				|| $_SERVER['SERVER_PORT'] == 443) {
+			header('strict-transport-security: max-age=31557600');
+		}
 
 		global $ZBX_SERVER_NAME;
 
