@@ -50,9 +50,9 @@ $servicesFormList->addRow(_('Parent service'), [
 	(new CDiv())->addClass(ZBX_STYLE_FORM_INPUT_MARGIN),
 	(new CButton('select_parent', _x('Change', 'verb')))
 		->addClass(ZBX_STYLE_BTN_GREY)
-		->onClick(
-			"javascript: openWinCentered('services.php?pservices=1".url_param('serviceid')."', ".
-				"'ZBX_Services_List', 740, 420, 'scrollbars=1, toolbar=0, menubar=0, resizable=1, dialog=0');")
+		->onClick('return PopUp("services.php?pservices=1'.url_param('serviceid').
+			'&parentid="+this.form.parentid.value);'
+		)
 ]);
 
 // append algorithm to form list
@@ -126,7 +126,9 @@ $servicesDependenciesFormList->addRow(
 	(new CDiv([
 		$servicesChildTable,
 		(new CButton('add_child_service', _('Add')))
-			->onClick("javascript: openWinCentered('services.php?cservices=1".url_param('serviceid')."', 'ZBX_Services_List', 640, 520, 'scrollbars=1, toolbar=0, menubar=0, resizable=0');")
+			->onClick('return PopUp("services.php?cservices=1'.url_param('serviceid').
+				'&parentid="+this.form.parentid.value);'
+			)
 			->addClass(ZBX_STYLE_BTN_LINK)
 	]))
 		->addClass(ZBX_STYLE_TABLE_FORMS_SEPARATOR)
