@@ -54,17 +54,16 @@ global $ZBX_SERVER_NAME;
 					])
 					->addItem([new CLabel(_('Password'), 'password'), (new CTextBox('password'))->setType('password')])
 					->addItem(
-						new CLabel([
-							(new CCheckBox('autologin'))->setChecked(getRequest('autologin', 1) == 1),
-							_('Remember me for 30 days')
-						], 'autologin')
+						(new CCheckBox('autologin'))
+							->setLabel(_('Remember me for 30 days'))
+							->setChecked(getRequest('autologin', 1) == 1)
 					)
 					->addItem(new CSubmit('enter', _('Sign in')))
 					->addItem($guest)
 			)
 	]))->addClass(ZBX_STYLE_SIGNIN_CONTAINER),
 	(new CDiv([
-		(new CLink(_('Help'), 'http://www.zabbix.com/documentation/3.2/'))
+		(new CLink(_('Help'), 'http://www.zabbix.com/documentation/3.4/'))
 			->setTarget('_blank')
 			->addClass(ZBX_STYLE_GREY)
 			->addClass(ZBX_STYLE_LINK_ALT),
